# PetLang
This is an internal language meant to empower the user with th possibility to create scripts that will allow them to create stories with their favorite characters (virtual people [i.e. Default man]) on their desktop.
